# Changelog

All notable changes to this project will be documented in this file.

For information on changes in GLFW itself, see the [GLFW version history](https://www.glfw.org/changelog.html).

## [1.8.1] - 2019-05-21
- Added the changelog back to the source distribution

## [1.8.0] - 2019-05-11
- Update for GLFW 3.3
- Fixed typo `set_get_window_frame_size`

## [1.7.1] - 2019-02-02
- Fixed exception re-raising for Python 2

## [1.7.0] - 2018-07-09
- Added glfw.GLFW for the naming convention used by the GLFW C API

## [1.6.0] - 2018-03-30
- Added NORMALIZE_GAMMA_RAMPS
- Use namedtuples for structs
- Moved library loading to glfw.library

## [1.5.1] - 2018-01-24
- Improved packaging

## [1.5.0] - 2018-01-09
- Fixed a bug in set_window_icon
- Added support for PIL/pillow Image objects

## [1.4.0] - 2017-02-22
- Improved library search paths

## [1.3.0] - 2016-07-28
- Improved error and exception handling

## [1.2.0] - 2016-06-17
- Update for GLFW 3.2

## [1.0.0] - 2014-03-23
- Initial release.
